netapp_ontap.models.nvme_service_statistics API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nvme_service_statistics`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NvmeServiceStatisticsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NvmeServiceStatistics object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `fc: PerformanceMetricRawSvm GET`

    The fc field of the nvme_service_statistics.

  `iops_raw: PerformanceMetricIoType GET`

    The iops_raw field of the nvme_service_statistics.

  `latency_raw: PerformanceMetricIoType GET`

    The latency_raw field of the nvme_service_statistics.

  `status: str GET`

    Any errors associated with the sample. For example, if the aggregation of data over multiple nodes fails then any of the partial errors might be returned, "ok" on success, or "error" on any internal uncategorized failure. Whenever a sample collection is missed but done at a later time, it is back filled to the previous 15 second timestamp and tagged with "backfilled_data". "Inconsistent_delta_time" is encountered when the time between two collections is not the same for all nodes. Therefore, the aggregated value might be over or under inflated. "Negative_delta" is returned when an expected monotonically increasing value has decreased in value. "Inconsistent_old_data" is returned when one or more nodes do not have the latest data.

    Valid choices:

    - ok
    - error
    - partial_no_data
    - partial_no_response
    - partial_other_error
    - negative_delta
    - not_found
    - backfilled_data
    - inconsistent_delta_time
    - inconsistent_old_data
    - partial_no_uuid
  `tcp: PerformanceMetricRawSvm GET`

    The tcp field of the nvme_service_statistics.

  `throughput_raw: PerformanceMetricIoTypeRwt GET`

    The throughput_raw field of the nvme_service_statistics.

  `timestamp: ImpreciseDateTime GET`

    The timestamp of the performance data.

    Example: 2017-01-25T11:20:13.000+0000